@@ -48,12 +48,10 @@ class ModelsEvaluator:
             for feature_vector, label in zip(X_eval, y_eval):
 
                 log_probs = model(feature_vector)
-                print("log_probs :", log_probs)
                 # get confidence that item is disaster-related
                 prob_related = math.exp(log_probs.data.tolist()[0][1])
-                print("prob_related :", prob_related)
 
-                if(label == 1):
+                if(label == "1"):
                     # true label is disaster related
                     related_confs.append(prob_related)
                     if prob_related > 0.5:
