@@ -931,6 +931,33 @@ class DataCorresponder:
         
         return X_data, y_data, id_data
 
+class DataLazyCorresponder:
+    def __init__(self, all_vec_data_path):
+        self.all_vec_data_path = all_vec_data_path
+    
+    def get_vec_correspondence(self, data_text):
+        if not data_text :
+            raise Exception("data_text cannot be empty")
+
+        X_data, y_data, id_data  = [], [], []
+        with open(self.all_vec_data_path, 'rb') as pickle_file:
+            try:
+                while True:
+                    result = pickle.load(pickle_file)
+                    vec_result, target_result, id_result = result
+                    id_result, target_result = id_result.decode("utf-8"), target_result.decode("utf-8")
+                    for item in data_text:
+                        id = item[0]
+                        label = item[2]
+                        if id == id_result:
+                            X_data.append(vec_result)
+                            y_data.append(label)
+                            id_data.append(int(id))
+                    vec, target, _id = result
+            except EOFError:
+                pass
+        return X_data, y_data, id_data
+
 class DataAdapter:
     def __init__(self):
         self.featuresHandler = FeaturesHandler()
@@ -1157,6 +1184,31 @@ class ConfigHandler:
         else:
             configGen.by_args(sys.argv, config_path)
 
+
+
+class LazyFileDataDumper:
+    def __init__(self,featuresHandler,feature_index):
+        self.featuresHandler = featuresHandler
+        self.feature_index = feature_index
+
+    def _save_objects(self, file_dest, objects):
+        with open(file_dest, 'ab') as output:  # Note: `ab` appends the data 
+            pickle.dump(objects, output, pickle.HIGHEST_PROTOCOL)
+
+    def dump(self, file_source, file_dest):
+        with open(file_source, 'rb') as infile:
+            for line in infile:
+                items = line.split(b',')
+                _id = items[0]
+                features = items[1].split()
+                feature_vec = self.featuresHandler.make_feature_vector(features,self.feature_index)
+                target = ""
+                if len(items) > 2:
+                    target = items[2]
+                
+                self._save_objects(file_dest, (feature_vec,target,_id))
+
+
 class VectorsInternalDataSpliter:
     def split(self, data, counter):
         assert len(data) == 3
